=======
Credits
=======

Development Lead
----------------

* Software design: **Kwangbom "KB" Choi, Ph. D.**, The Jackson Laboratory <kb.choi@jax.org>
* Software engineering: **Matthew Vincent**, The Jackson Laboratory <matt.vincent@jax.org>

Contributors
------------

* Narayanan Raghupathy, The Jackson Laboratory <Narayanan.Raghupathy@jax.org>
* Anuj Srivastava, The Jackson Laboratory <Anuj.Srivastava@jax.org>
